@@ -34,7 +34,7 @@ import sys
 
 from py_swtpm_setup.swtpm_utils import logit, logerr, sha1
 from py_swtpm_setup.swtpm_setup_conf import SWTPM_VER_MAJOR, SWTPM_VER_MINOR, \
-                                            SWTPM_VER_MICRO
+                                            SWTPM_VER_MICRO, SYSCONFDIR
 from py_swtpm_setup.swtpm import Swtpm2, Swtpm12
 
 # default values for passwords
@@ -64,10 +64,10 @@ XCH = os.getenv('XDG_CONFIG_HOME')
 HOME = os.getenv('HOME')
 if XCH and os.access(os.path.join(XCH, SWTPM_SETUP_CONF), os.R_OK):
     DEFAULT_CONFIG_FILE = os.path.join(XCH, SWTPM_SETUP_CONF)
-elif HOME and os.access(os.path.join(HOME, SWTPM_SETUP_CONF), os.R_OK):
-    DEFAULT_CONFIG_FILE = os.path.join(HOME, SWTPM_SETUP_CONF)
+elif HOME and os.access(os.path.join(HOME, ".config", SWTPM_SETUP_CONF), os.R_OK):
+    DEFAULT_CONFIG_FILE = os.path.join(HOME, ".config", SWTPM_SETUP_CONF)
 else:
-    DEFAULT_CONFIG_FILE = os.path.join(os.sep + 'etc', SWTPM_SETUP_CONF)
+    DEFAULT_CONFIG_FILE = os.path.join(os.sep + SYSCONFDIR, SWTPM_SETUP_CONF)
 
 # default PCR banks to activate for TPM 2
 DEFAULT_PCR_BANKS = "sha1,sha256"
@@ -161,7 +161,7 @@ def tpm_get_specs_and_attributes(swtpm):
         tpm_param = json.loads(res)
     except json.decoder.JSONDecodeError as err:
         logerr(LOGFILE, "Internal error: Could not parse '%s' as JSON: %s\n" %
-               (instr, str(err)))
+               (res, str(err)))
         return [], 1
 
     params = ["--tpm-spec-family", tpm_param["TPMSpecification"]["family"],
@@ -662,7 +662,7 @@ def main():
         swtpm_prg += " socket"
 
     try:
-        opts, _ = getopt.getopt(sys.argv[1:], "",
+        opts, _ = getopt.getopt(sys.argv[1:], "h?",
                                 ["tpm-state=", "tpmstate=",
                                  "tpm=",
                                  "swtpm_ioctl=",
@@ -697,7 +697,7 @@ def main():
                                  "tcsd-system-ps-file",
                                  "version",
                                  "print-capabilities",
-                                 "help", "h"])
+                                 "help"])
     except getopt.GetoptError as err:
         print(err)
         usage(sys.argv[0])
